@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::PERLANCAR;
 
-our $DATE = '2016-04-13'; # DATE
-our $VERSION = '0.50'; # VERSION
+our $DATE = '2016-06-30'; # DATE
+our $VERSION = '0.51'; # VERSION
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -33,7 +33,7 @@ sub configure {
         'OurDist',
         'PERLANCAR::OurPkgVersion',
         'PodWeaver',
-        ['PruneFiles' => {match => ['~$']}],
+        ['PruneFiles' => {match => ['~$', '^nytprof.*']}],
         'ReadmeFromPod',
         'Rinci::AddPrereqs',
         'Rinci::AddToDb',
@@ -64,7 +64,7 @@ Dist::Zilla::PluginBundle::Author::PERLANCAR - Dist::Zilla like PERLANCAR when y
 
 =head1 VERSION
 
-This document describes version 0.50 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2016-04-13.
+This document describes version 0.51 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2016-06-30.
 
 =head1 SYNOPSIS
 
